/*++

Copyright (c) 1997-1998 Microsoft Corporation

Module Name:

    VNDRLIST.H

Abstract:

    This header file contains a list of all currently known USB Vendor IDs
    the vendor name associated with each Vendor ID

Environment:

    Kernel & user mode

Revision History:

    04-25-97 : created

--*/

#ifndef   __VNDRLIST_H__
#define   __VNDRLIST_H__

//
// Vendor ID structure
//
typedef struct {
    USHORT  usVendorID;
    PCHAR   szVendor;
} USBVENDORID, *PUSBVENDORID;

//
// This list built from information obtained on Nov-30-2000 from
// http://www.usb.org
//
// This information has not been independently verified and no claims
// are made here as to its accuracy.
//

USBVENDORID USBVendorIDs[] =
{
    { 1000, /* 0x03E8 */ "EndPoints Inc."},
    { 1001, /* 0x03E9 */ "Thesys Microelectronics"},
    { 1003, /* 0x03EB */ "Atmel Corporation"},
    { 1006, /* 0x03EE */ "Mitsumi"},
    { 1008, /* 0x03F0 */ "Hewlett Packard"},
    { 1010, /* 0x03F2 */ "Oak Technology, Inc"},
    { 1011, /* 0x03F3 */ "Adaptec, Inc."},
    { 1012, /* 0x03F4 */ "Diebold, Inc."},
    { 1017, /* 0x03F9 */ "KeyTronic Corp."},
    { 1019, /* 0x03FB */ "OPTi Inc."},
    { 1022, /* 0x03FE */ "Farallon Comunications"},
    { 1024, /* 0x0400 */ "National Semiconductor"},
    { 1026, /* 0x0402 */ "Acer Labs Inc."},
    { 1027, /* 0x0403 */ "Future Technology Devices International Limited"},
    { 1028, /* 0x0404 */ "NCR Corporation"},
    { 1029, /* 0x0405 */ "inSilicon"},
    { 1033, /* 0x0409 */ "NEC Corporation"},
    { 1034, /* 0x040A */ "Kodak Co."},
    { 1035, /* 0x040B */ "Weltrend Semiconductor"},
    { 1037, /* 0x040D */ "VIA Technologies, Inc."},
    { 1038, /* 0x040E */ "MCCI"},
    { 1041, /* 0x0411 */ "Melco, Inc."},
    { 1046, /* 0x0416 */ "Winbond Electronics Corp."},
    { 1050, /* 0x041A */ "Phoenix Technologies Ltd."},
    { 1054, /* 0x041E */ "Creative Labs"},
    { 1057, /* 0x0421 */ "Nokia Mobile Phones"},
    { 1058, /* 0x0422 */ "ADI Systems Inc."},
    { 1059, /* 0x0423 */ "CATC"},
    { 1060, /* 0x0424 */ "Standard Microsystems Corp."},
    { 1061, /* 0x0425 */ "Motorola Semiconductors HK, Ltd."},
    { 1065, /* 0x0429 */ "Cirrus Logic Inc."},
    { 1068, /* 0x042C */ "Innovative Semiconductors, Inc."},
    { 1072, /* 0x0430 */ "Fujitsu Takamisawa America"},
    { 1074, /* 0x0432 */ "Unisys Corp."},
    { 1078, /* 0x0436 */ "Taugagreining HF"},
    { 1080, /* 0x0438 */ "Advanced Micro Devices"},
    { 1085, /* 0x043D */ "Lexmark International Inc."},
    { 1086, /* 0x043E */ "LG Electronics USA Inc."},
    { 1088, /* 0x0440 */ "EIZO NANAO CORPORATION"},
    { 1091, /* 0x0443 */ "Gateway 2000"},
    { 1093, /* 0x0445 */ "Lucent Technologies"},
    { 1094, /* 0x0446 */ "NMB Technologies, Inc."},
    { 1102, /* 0x044E */ "Alps Electric Co., Ltd."},
    { 1103, /* 0x044F */ "ThrustMaster, Inc."},
    { 1105, /* 0x0451 */ "Texas Instruments"},
    { 1106, /* 0x0452 */ "Mitsubishi Electric & Electronics US, Inc."},
    { 1110, /* 0x0456 */ "Analog Devices, Inc."},
    { 1111, /* 0x0457 */ "Silicon Integrated Systems Corp."},
    { 1114, /* 0x045A */ "Diamond Multimedia Systems"},
    { 1115, /* 0x045B */ "Hitachi, Ltd (2)"},
    { 1118, /* 0x045E */ "Microsoft Corporation"},
    { 1121, /* 0x0461 */ "Primax Electronics"},
    { 1123, /* 0x0463 */ "MGE UPS Systems"},
    { 1124, /* 0x0464 */ "AMP/Tycoelectronics"},
    { 1128, /* 0x0468 */ "Wieson Electronic Co., Ltd."},
    { 1130, /* 0x046A */ "Cherry GMBH"},
    { 1132, /* 0x046C */ "Toshiba Corporation, Digital Media Equipment"},
    { 1133, /* 0x046D */ "Logitech Inc."},
    { 1134, /* 0x046E */ "Behavior Tech. Computer Corporation"},
    { 1137, /* 0x0471 */ "Philips"},
    { 1138, /* 0x0472 */ "Sun Microsystems"},
    { 1140, /* 0x0474 */ "Sanyo Electric Co. Ltd."},
    { 1141, /* 0x0475 */ "TECO Electric & Machinery Co., Ltd."},
    { 1146, /* 0x047A */ "USAR Systems Incorporated"},
    { 1147, /* 0x047B */ "Silitek Corp."},
    { 1149, /* 0x047D */ "Kensington"},
    { 1150, /* 0x047E */ "Lucent Microelectronics Technologies"},
    { 1151, /* 0x047F */ "Plantronics, Inc."},
    { 1154, /* 0x0482 */ "Kyocera Tech. Development, Inc."},
    { 1155, /* 0x0483 */ "STMicroelectronics"},
    { 1160, /* 0x0488 */ "Cirque Corporation"},
    { 1161, /* 0x0489 */ "Foxconn / Hon Hai"},
    { 1165, /* 0x048D */ "Integrated Technology Express"},
    { 1169, /* 0x0491 */ "Capetronic Kaohsiung Corp."},
    { 1170, /* 0x0492 */ "Samsung SemiConductor, Inc."},
    { 1174, /* 0x0496 */ "Micron Electronics"},
    { 1175, /* 0x0497 */ "Smile International, Inc."},
    { 1177, /* 0x0499 */ "Yamaha Corporation"},
    { 1179, /* 0x049B */ "Curtis Computer Products"},
    { 1183, /* 0x049F */ "Compaq Computer Corporation"},
    { 1188, /* 0x04A4 */ "Hitachi, Ltd."},
    { 1189, /* 0x04A5 */ "Acer Communications & Multimedia Inc."},
    { 1192, /* 0x04A8 */ "Multivideo Labs, Inc."},
    { 1193, /* 0x04A9 */ "Canon Inc. (Kosugi Office)"},
    { 1201, /* 0x04B1 */ "Pan International"},
    { 1203, /* 0x04B3 */ "IBM Corporation"},
    { 1204, /* 0x04B4 */ "Cypress Semiconductor"},
    { 1205, /* 0x04B5 */ "ROHM LSI Systems USA, LLC"},
    { 1207, /* 0x04B7 */ "Compal Electronics, Inc."},
    { 1208, /* 0x04B8 */ "Seiko Epson Corp."},
    { 1209, /* 0x04B9 */ "Rainbow Technologies, Inc."},
    { 1211, /* 0x04BB */ "I-O Data Device, Inc."},
    { 1215, /* 0x04BF */ "TDK Corporation"},
    { 1221, /* 0x04C5 */ "Fujitsu Ltd."},
    { 1224, /* 0x04C8 */ "Konica Corporation"},
    { 1227, /* 0x04CB */ "Fuji Photo Film Co., Ltd."},
    { 1228, /* 0x04CC */ "Philips Semiconductors"},
    { 1230, /* 0x04CE */ "ScanLogic Corporation"},
    { 1231, /* 0x04CF */ "Myson Technology Inc."},
    { 1236, /* 0x04D4 */ "LSI Logic Corporation"},
    { 1238, /* 0x04D6 */ "Mentor Graphics"},
    { 1239, /* 0x04D7 */ "Oki Semiconductor"},
    { 1240, /* 0x04D8 */ "Microchip Technology Inc."},
    { 1241, /* 0x04D9 */ "Holtek Semiconductor, Inc."},
    { 1242, /* 0x04DA */ "Panasonic (Matsushita)"},
    { 1245, /* 0x04DD */ "Sharp Corporation"},
    { 1246, /* 0x04DE */ "MindShare, Inc."},
    { 1254, /* 0x04E6 */ "SCM Microsystems"},
    { 1255, /* 0x04E7 */ "Elo TouchSystems"},
    { 1257, /* 0x04E9 */ "PC-Tel,  Inc."},
    { 1258, /* 0x04EA */ "Sipex Corporation"},
    { 1259, /* 0x04EB */ "Northstar Systems, Inc."},
    { 1260, /* 0x04EC */ "Tokyo Electron Device Limited"},
    { 1261, /* 0x04ED */ "Annabooks"},
    { 1265, /* 0x04F1 */ "Victor Company of Japan, Limited"},
    { 1266, /* 0x04F2 */ "Chicony Electronics Co., Ltd."},
    { 1267, /* 0x04F3 */ "Elan Microelectronics Corportation"},
    { 1271, /* 0x04F7 */ "Newnex Technology Corp."},
    { 1272, /* 0x04F8 */ "FuturePlus Systems"},
    { 1274, /* 0x04FA */ "Dallas Semiconductor"},
    { 1276, /* 0x04FC */ "SUNPLUS TECHNOLOGY CO., LTD."},
    { 1277, /* 0x04FD */ "Soliton Systems K.K."},
    { 1279, /* 0x04FF */ "E-CMOS Corp."},
    { 1281, /* 0x0501 */ "FAI/DDK Connector Division"},
    { 1282, /* 0x0502 */ "Acer, Inc."},
    { 1286, /* 0x0506 */ "3Com Corporation"},
    { 1287, /* 0x0507 */ "Hosiden Corporation"},
    { 1289, /* 0x0509 */ "Aztech Systems Ltd"},
    { 1293, /* 0x050D */ "Belkin Components"},
    { 1295, /* 0x050F */ "KC Technology Inc."},
    { 1296, /* 0x0510 */ "Sejin Electron Inc."},
    { 1300, /* 0x0514 */ "FCI Electronics"},
    { 1302, /* 0x0516 */ "Longwell Electronics/Longwell Company"},
    { 1308, /* 0x051C */ "Shuttle Inc."},
    { 1309, /* 0x051D */ "American Power Conversion"},
    { 1311, /* 0x051F */ "IO Systems Inc. fomerly Elite Electronics, Inc."},
    { 1314, /* 0x0522 */ "Advanced Connectek USA Inc."},
    { 1317, /* 0x0525 */ "Netchip Technology Inc."},
    { 1318, /* 0x0526 */ "Temic MHS S.A."},
    { 1320, /* 0x0528 */ "ATI Technologies, Inc."},
    { 1321, /* 0x0529 */ "Aladdin Knowledge Systems"},
    { 1322, /* 0x052A */ "Crescent Heart Software"},
    { 1323, /* 0x052B */ "Tekom Technologies, Inc"},
    { 1324, /* 0x052C */ "Canon Information Systems, Inc."},
    { 1329, /* 0x0531 */ "Wacom Technology Corp."},
    { 1335, /* 0x0537 */ "Inventec Corporation"},
    { 1337, /* 0x0539 */ "Shyh Shiun Terminals Co. LTD"},
    { 1338, /* 0x053A */ "Preh Werke Gmbh & Co. KG"},
    { 1342, /* 0x053E */ "Mobility Electronics"},
    { 1343, /* 0x053F */ "Synopsys, Inc."},
    { 1347, /* 0x0543 */ "ViewSonic Corporation"},
    { 1349, /* 0x0545 */ "Xirlink, Inc."},
    { 1350, /* 0x0546 */ "Polaroid Corporation"},
    { 1354, /* 0x054A */ "Fujitsu Microelectronics, Inc."},
    { 1356, /* 0x054C */ "Sony Corporation"},
    { 1360, /* 0x0550 */ "Fuji Xerox Co., Ltd."},
    { 1363, /* 0x0553 */ "STMicroelectronics Imaging Division"},
    { 1366, /* 0x0556 */ "Asahi Kasei Microsystems Co., Ltd"},
    { 1367, /* 0x0557 */ "ATEN International Co. Ltd."},
    { 1369, /* 0x0559 */ "Cadence Design Systems, Inc."},
    { 1373, /* 0x055D */ "Samsung Electro-Mechanics Co."},
    { 1374, /* 0x055E */ "Optoma Corporation"},
    { 1378, /* 0x0562 */ "Telex Communications Inc."},
    { 1379, /* 0x0563 */ "Immersion Corporation"},
    { 1380, /* 0x0564 */ "Chinon Industries, Inc."},
    { 1386, /* 0x056A */ "WACOM Co., Ltd."},
    { 1388, /* 0x056C */ "e-TEK Labs"},
    { 1390, /* 0x056E */ "Elecom Co., Ltd."},
    { 1391, /* 0x056F */ "Korea Data Systems Co., Ltd."},
    { 1393, /* 0x0571 */ "XLR8, Inc."},
    { 1394, /* 0x0572 */ "Conexant Systems, Inc."},
    { 1395, /* 0x0573 */ "Nogatech Ltd."},
    { 1397, /* 0x0575 */ "Philips Creative Display Solutions"},
    { 1398, /* 0x0576 */ "BAFO/Quality Computer Accessories"},
    { 1403, /* 0x057B */ "Y-E Data, Inc."},
    { 1404, /* 0x057C */ "AVM GmbH"},
    { 1405, /* 0x057D */ "Shark Multimedia Inc."},
    { 1406, /* 0x057E */ "Nintendo Co., Ltd."},
    { 1410, /* 0x0582 */ "Roland Corporation"},
    { 1411, /* 0x0583 */ "Padix Co., Ltd."},
    { 1412, /* 0x0584 */ "RATOC System Inc."},
    { 1413, /* 0x0585 */ "FlashPoint Technology, Inc."},
    { 1419, /* 0x058B */ "Infineon Technologies"},
    { 1420, /* 0x058C */ "In Focus Systems"},
    { 1421, /* 0x058D */ "Micrel Semiconductor"},
    { 1423, /* 0x058F */ "Alcor Micro, Inc."},
    { 1424, /* 0x0590 */ "OMRON Corporation"},
    { 1426, /* 0x0592 */ "Powerware Corporation"},
    { 1429, /* 0x0595 */ "Zoran Microelectronics Ltd."},
    { 1430, /* 0x0596 */ "MicroTouch Systems Inc."},
    { 1432, /* 0x0598 */ "Niigata Canotec Co., Inc."},
    { 1435, /* 0x059B */ "Iomega Corporation"},
    { 1437, /* 0x059D */ "Advanced Input Devices"},
    { 1438, /* 0x059E */ "Intelligent Instrumentation"},
    { 1439, /* 0x059F */ "LaCie"},
    { 1442, /* 0x05A2 */ "Fuji Film Microdevices Co. Ltd."},
    { 1443, /* 0x05A3 */ "V Automation Inc."},
    { 1444, /* 0x05A4 */ "Ortek Technology, Inc."},
    { 1446, /* 0x05A6 */ "Cisco Systems, Inc."},
    { 1449, /* 0x05A9 */ "OmniVision Technologies, Inc."},
    { 1451, /* 0x05AB */ "In-System Design"},
    { 1452, /* 0x05AC */ "Apple Computer"},
    { 1453, /* 0x05AD */ "Y.C.Cable U.S.A., Inc"},
    { 1456, /* 0x05B0 */ "Fountain Technologies, Inc"},
    { 1460, /* 0x05B4 */ "HYUNDAI Electronics Industries Co., Ltd."},
    { 1466, /* 0x05BA */ "DigitalPersona, Inc."},
    { 1469, /* 0x05BD */ "RAFI GmbH & Co. KG"},
    { 1470, /* 0x05BE */ "Raychem Corporation"},
    { 1472, /* 0x05C0 */ "Keil Software"},
    { 1473, /* 0x05C1 */ "Kawasaki Steel"},
    { 1477, /* 0x05C5 */ "Digi International Inc."},
    { 1478, /* 0x05C6 */ "Qualcomm, Inc"},
    { 1479, /* 0x05C7 */ "Qtronix Corp"},
    { 1480, /* 0x05C8 */ "Cheng Uei Precision Industry Co., Ltd"},
    { 1482, /* 0x05CA */ "Ricoh Company Ltd."},
    { 1483, /* 0x05CB */ "PowerVision Technologies Inc."},
    { 1485, /* 0x05CD */ "Silicom LTD."},
    { 1486, /* 0x05CE */ "Sican GmbH"},
    { 1487, /* 0x05CF */ "Sung Forn Co. LTD."},
    { 1488, /* 0x05D0 */ "Lunar Corporation"},
    { 1489, /* 0x05D1 */ "Brainboxes Limited"},
    { 1496, /* 0x05D8 */ "Ultima Electronics Corp."},
    { 1497, /* 0x05D9 */ "Axiohm Transaction Solutions"},
    { 1498, /* 0x05DA */ "Microtek International Inc."},
    { 1499, /* 0x05DB */ "Sun Corporation"},
    { 1500, /* 0x05DC */ "Lexar Media, Inc."},
    { 1501, /* 0x05DD */ "Delta Electronics Inc."},
    { 1504, /* 0x05E0 */ "Symbol Technologies"},
    { 1507, /* 0x05E3 */ "Genesys Logic, Inc."},
    { 1509, /* 0x05E5 */ "Fuji Electric Co., Ltd."},
    { 1510, /* 0x05E6 */ "Keithley Instruments"},
    { 1513, /* 0x05E9 */ "Kawasaki LSI"},
    { 1519, /* 0x05EF */ "Anko Electronic Co., Ltd."},
    { 1520, /* 0x05F0 */ "Canopus Co., Ltd."},
    { 1523, /* 0x05F3 */ "PI Engineering, Inc"},
    { 1525, /* 0x05F5 */ "Unixtar Technology Inc."},
    { 1527, /* 0x05F7 */ "Silicon Portals Inc."},
    { 1529, /* 0x05F9 */ "PSC Scanning, Inc."},
    { 1533, /* 0x05FD */ "STD Manufacturing Ltd."},
    { 1534, /* 0x05FE */ "CHIC TECHNOLOGY CORP"},
    { 1535, /* 0x05FF */ "LeCroy Corporation"},
    { 1537, /* 0x0601 */ "Jazz Hipster Corporation"},
    { 1538, /* 0x0602 */ "Vista Imaging Inc."},
    { 1539, /* 0x0603 */ "Novatek Microelectronics Corp."},
    { 1540, /* 0x0604 */ "Jean Co, Ltd."},
    { 1543, /* 0x0607 */ "Bridge Information Co., Ltd."},
    { 1545, /* 0x0609 */ "SMK Manufacturing Inc."},
    { 1546, /* 0x060A */ "Worth Data, Inc."},
    { 1551, /* 0x060F */ "Joinsoon Electronics Mfg. Co., Ltd."},
    { 1553, /* 0x0611 */ "Totoku Electric Co., LTD."},
    { 1555, /* 0x0613 */ "TransAct Technologies Incorporated"},
    { 1556, /* 0x0614 */ "Bio-Rad Laboratories"},
    { 1558, /* 0x0616 */ "Future Techno Designs PVT. LTD."},
    { 1561, /* 0x0619 */ "Seiko Instruments Inc."},
    { 1564, /* 0x061C */ "Act Labs, Ltd."},
    { 1565, /* 0x061D */ "Quatech, Inc."},
    { 1566, /* 0x061E */ "Nissei Electric Co."},
    { 1568, /* 0x0620 */ "Alaris, Inc."},
    { 1569, /* 0x0621 */ "ODU-Steckverbindungssysteme GmbH & Co. KG"},
    { 1571, /* 0x0623 */ "Littelfuse, Inc."},
    { 1572, /* 0x0624 */ "Avocent Corporation"},
    { 1574, /* 0x0626 */ "Nippon Systems Development Co., Ltd."},
    { 1577, /* 0x0629 */ "Zida Technologies Limited"},
    { 1579, /* 0x062B */ "Greatlink Electronics Taiwan  Ltd."},
    { 1581, /* 0x062D */ "Taiwan Tai-Hao Enterprises Co. Ltd."},
    { 1582, /* 0x062E */ "Mainsuper Enterprises Co., Ltd."},
    { 1583, /* 0x062F */ "Sin Sheng Terminal & Machine Inc."},
    { 1588, /* 0x0634 */ "Micron Technology, Inc."},
    { 1590, /* 0x0636 */ "Sierra Imaging, Inc."},
    { 1592, /* 0x0638 */ "Avision, Inc."},
    { 1600, /* 0x0640 */ "Hitex Development Tools"},
    { 1601, /* 0x0641 */ "Woods Industries, Inc."},
    { 1604, /* 0x0644 */ "TEAC Corporation"},
    { 1605, /* 0x0645 */ "Ethentica Inc."},
    { 1611, /* 0x064B */ "White Mountain DSP, Inc."},
    { 1612, /* 0x064C */ "Ji-Haw Industrial Co., Ltd"},
    { 1615, /* 0x064F */ "WIBU-Systems AG"},
    { 1617, /* 0x0651 */ "Likom Technology Sdn. Bhd."},
    { 1618, /* 0x0652 */ "Stargate Solutions, Inc."},
    { 1620, /* 0x0654 */ "Granite Microsystems, Inc."},
    { 1621, /* 0x0655 */ "Space Shuttle Hi-Tech Co.,Ltd."},
    { 1622, /* 0x0656 */ "Glory Mark Electronic Ltd."},
    { 1623, /* 0x0657 */ "Tekcon American Corp."},
    { 1626, /* 0x065A */ "Optoelectronics Co., Ltd."},
    { 1631, /* 0x065F */ "Good Way Industrial Co, Ltd & GWC Technology Inc."},
    { 1632, /* 0x0660 */ "TSAY-E (BVI) International Inc."},
    { 1633, /* 0x0661 */ "Hamamatsu Photonics K.K."},
    { 1635, /* 0x0663 */ "Topmax Electronic Co., Ltd."},
    { 1641, /* 0x0669 */ "Oce' Printing Systems GmbH"},
    { 1642, /* 0x066A */ "Total Technologies, Ltd."},
    { 1647, /* 0x066F */ "SigmaTel, Inc."},
    { 1650, /* 0x0672 */ "Labtec Inc."},
    { 1652, /* 0x0674 */ "Key Mouse Electronic Enterprise Co., Ltd."},
    { 1653, /* 0x0675 */ "DrayTek Corp."},
    { 1654, /* 0x0676 */ "Teles AG"},
    { 1656, /* 0x0678 */ "ACARD Technology Corp."},
    { 1659, /* 0x067B */ "Prolific Technology, Inc."},
    { 1660, /* 0x067C */ "Efficient Networks, Inc."},
    { 1662, /* 0x067E */ "Intermec"},
    { 1663, /* 0x067F */ "Virata Ltd."},
    { 1664, /* 0x0680 */ "Avance Logic, Inc."},
    { 1665, /* 0x0681 */ "Siemens Information and Communication Products"},
    { 1670, /* 0x0686 */ "Minolta Co., Ltd."},
    { 1674, /* 0x068A */ "Pertech Inc."},
    { 1680, /* 0x0690 */ "Golden Bridge Electech Inc."},
    { 1683, /* 0x0693 */ "Hagiwara Sys-Com Co., Ltd."},
    { 1684, /* 0x0694 */ "The LEGO Company"},
    { 1688, /* 0x0698 */ "Chuntex (CTX)"},
    { 1689, /* 0x0699 */ "Tektronix, Inc."},
    { 1690, /* 0x069A */ "Askey Computer Corporation"},
    { 1691, /* 0x069B */ "Thomson Consumer Electronics"},
    { 1693, /* 0x069D */ "Hughes Network Systems (HNS)"},
    { 1698, /* 0x06A2 */ "Topro Technology Inc."},
    { 1699, /* 0x06A3 */ "Saitek PLC"},
    { 1701, /* 0x06A5 */ "Divio"},
    { 1705, /* 0x06A9 */ "Westell"},
    { 1706, /* 0x06AA */ "Sysgration Ltd."},
    { 1708, /* 0x06AC */ "Fujitsu PC Corporation"},
    { 1710, /* 0x06AE */ "Professional Multimedia Testing Centre"},
    { 1720, /* 0x06B8 */ "Pixela Corproation"},
    { 1721, /* 0x06B9 */ "Alcatel Telecom"},
    { 1722, /* 0x06BA */ "Smooth Cord & Connector Co., Ltd."},
    { 1723, /* 0x06BB */ "EDA Inc."},
    { 1724, /* 0x06BC */ "Oki Data Corporation"},
    { 1725, /* 0x06BD */ "AGFA-Gevaert NV"},
    { 1727, /* 0x06BF */ "Leoco Corporation"},
    { 1732, /* 0x06C4 */ "Bizlink International Corporation"},
    { 1736, /* 0x06C8 */ "SIIG, Inc."},
    { 1740, /* 0x06CC */ "Terayon Communication Systems"},
    { 1741, /* 0x06CD */ "Keyspan"},
    { 1747, /* 0x06D3 */ "Mitsubishi Electric Corporation"},
    { 1754, /* 0x06DA */ "Phoenixtec Power Co., Ltd."},
    { 1755, /* 0x06DB */ "Paradyne"},
    { 1756, /* 0x06DC */ "Compeye Corporation"},
    { 1758, /* 0x06DE */ "Heisei Electronics Co. Ltd."},
    { 1760, /* 0x06E0 */ "Multi-Tech Systems, Inc."},
    { 1764, /* 0x06E4 */ "Alcatel Microelectronics"},
    { 1766, /* 0x06E6 */ "Tiger Jet Network, Inc."},
    { 1778, /* 0x06F2 */ "Machkey  International (USA)"},
    { 1789, /* 0x06FD */ "Boston Acoustics"},
    { 1793, /* 0x0701 */ "Supercomal Wire & Cable SDN. BHD."},
    { 1797, /* 0x0705 */ "NKK Corporation"},
    { 1801, /* 0x0709 */ "Parthus Technologies"},
    { 1802, /* 0x070A */ "Oki Electric Industry Co., Ltd"},
    { 1805, /* 0x070D */ "Comoss Electronic Co., Ltd."},
    { 1808, /* 0x0710 */ "Connect Tech Inc."},
    { 1809, /* 0x0711 */ "Magic Control Technology Corp."},
    { 1816, /* 0x0718 */ "Imation Corp."},
    { 1817, /* 0x0719 */ "Tremon Enterprises Co., Ltd."},
    { 1821, /* 0x071D */ "Eicon Technology Corporation"},
    { 1827, /* 0x0723 */ "Centillium Communications Corporation"},
    { 1830, /* 0x0726 */ "Vanguard International Semiconductor-America"},
    { 1841, /* 0x0731 */ "SusTeen, Inc."},
    { 1843, /* 0x0733 */ "ViewQuest Technologies, Inc."},
    { 1844, /* 0x0734 */ "LASAT Communications A/S"},
    { 1848, /* 0x0738 */ "Mad Catz, Inc."},
    { 1862, /* 0x0746 */ "ONKYO Corporation"},
    { 1864, /* 0x0748 */ "Strong Man Enterprise Co., Ltd."},
    { 1868, /* 0x074C */ "C-C-C Group PLC"},
    { 1869, /* 0x074D */ "Micronas GmbH"},
    { 1870, /* 0x074E */ "Digital Stream Corporation"},
    { 1879, /* 0x0757 */ "Network Technologies, Inc."},
    { 1892, /* 0x0764 */ "Cyber Power System, Inc."},
    { 1893, /* 0x0765 */ "X-Rite Incorporated"},
    { 1896, /* 0x0768 */ "Camtel Technology Corp."},
    { 1897, /* 0x0769 */ "Surecom Technology Corp."},
    { 1898, /* 0x076A */ "Conceptual Systems"},
    { 1899, /* 0x076B */ "OMNIKEY AG"},
    { 1900, /* 0x076C */ "Partner Tech"},
    { 1901, /* 0x076D */ "Denso Corporation"},
    { 1910, /* 0x0776 */ "Inalways Corporation"},
    { 1911, /* 0x0777 */ "Comda Enterprise Corporation"},
    { 1913, /* 0x0779 */ "Fairchild Semiconductor"},
    { 1914, /* 0x077A */ "Sankyo Seiki Mfg. Co., Ltd."},
    { 1915, /* 0x077B */ "Linksys"},
    { 1916, /* 0x077C */ "Forward Electronics Co., Ltd."},
    { 1921, /* 0x0781 */ "SanDisk Corporation"},
    { 1922, /* 0x0782 */ "Trackerball"},
    { 1929, /* 0x0789 */ "Logitec Corporation"},
    { 1934, /* 0x078E */ "Brimax Inc."},
    { 1936, /* 0x0790 */ "Pro-Image Manufacturing Co., Ltd"},
    { 1937, /* 0x0791 */ "Copartner Wire and Cable Mfg. Corp."},
    { 1938, /* 0x0792 */ "Axis Communications AB"},
    { 1939, /* 0x0793 */ "Wha Yu Industrial Co., Ltd."},
    { 1940, /* 0x0794 */ "ABL Electronics Corporation"},
    { 1941, /* 0x0795 */ "RealChip Inc."},
    { 1942, /* 0x0796 */ "Certicom Corp."},
    { 1943, /* 0x0797 */ "Grandtech Semiconductor Corporation"},
    { 1949, /* 0x079D */ "Alfadata Computer Corp."},
    { 1954, /* 0x07A2 */ "National Technical Systems"},
    { 1955, /* 0x07A3 */ "ONNTO Corp."},
    { 1956, /* 0x07A4 */ "Be Incorporated"},
    { 1958, /* 0x07A6 */ "ADMtek Incorporated"},
    { 1962, /* 0x07AA */ "correga K.K."},
    { 1963, /* 0x07AB */ "Freecom Technologies"},
    { 1969, /* 0x07B1 */ "IMP, Inc."},
    { 1971, /* 0x07B3 */ "Plustek, Inc."},
    { 1972, /* 0x07B4 */ "Olympus Optical Co., Ltd."},
    { 1973, /* 0x07B5 */ "Mega World International Ltd."},
    { 1974, /* 0x07B6 */ "Marubun Corp."},
    { 1975, /* 0x07B7 */ "TIME Interconect Ltd."},
    { 1976, /* 0x07B8 */ "AboCom Systems, Inc."},
    { 1980, /* 0x07BC */ "Canon Computer Sytems, Inc."},
    { 1982, /* 0x07BE */ "Veridicom"},
    { 1988, /* 0x07C4 */ "Datafab Systems Inc."},
    { 1989, /* 0x07C5 */ "APG Cash Drawer"},
    { 1990, /* 0x07C6 */ "Share Wave, Inc."},
    { 1991, /* 0x07C7 */ "Powertech Industrial Co., Ltd."},
    { 1993, /* 0x07C9 */ "Allied Telesyn International"},
    { 1995, /* 0x07CB */ "Kingmax Technology Inc."},
    { 1996, /* 0x07CC */ "Carry Computer Eng., Co., Ltd."},
    { 2003, /* 0x07D3 */ "Cyberdata Corp."},
    { 2007, /* 0x07D7 */ "GCC Technologies, Inc."},
    { 2010, /* 0x07DA */ "Arasan Chip Systems"},
    { 2015, /* 0x07DF */ "David Electronics Company, Ltd."},
    { 2018, /* 0x07E2 */ "Elmeg GmbH & Co., Ltd."},
    { 2019, /* 0x07E3 */ "Planex Communications, Inc."},
    { 2020, /* 0x07E4 */ "Movado Enterprise Co., Ltd."},
    { 2021, /* 0x07E5 */ "QPS, Inc."},
    { 2022, /* 0x07E6 */ "Allied Cable Corporation"},
    { 2024, /* 0x07E8 */ "Labsystems"},
    { 2026, /* 0x07EA */ "Iwatsu Electric Co., Ltd."},
    { 2027, /* 0x07EB */ "Double-H Technology Co., Ltd."},
    { 2028, /* 0x07EC */ "Taiyo Electrical Wire & Cable Co., Ltd."},
    { 2039, /* 0x07F7 */ "Century Corporation"},
    { 2041, /* 0x07F9 */ "Dotop Technology, Inc."},
    { 2049, /* 0x0801 */ "Mag-Tek"},
    { 2050, /* 0x0802 */ "Infineer Inc."},
    { 2051, /* 0x0803 */ "Zoom Telephonics, Inc."},
    { 2057, /* 0x0809 */ "Genicom Corp."},
    { 2058, /* 0x080A */ "Evermuch Technology Co., Ltd."},
    { 2061, /* 0x080D */ "TECO Image Systems Co., Ltd."},
    { 2064, /* 0x0810 */ "Personal Communication Systems, Inc."},
    { 2067, /* 0x0813 */ "Mattel, Inc."},
    { 2078, /* 0x081E */ "AlphaSmart, Inc."},
    { 2082, /* 0x0822 */ "REUDO Corporation"},
    { 2086, /* 0x0826 */ "Data Transit"},
    { 2087, /* 0x0827 */ "BroadLogic, Inc."},
    { 2088, /* 0x0828 */ "Sato Corporation"},
    { 2089, /* 0x0829 */ "Telocity, Inc"},
    { 2096, /* 0x0830 */ "Palm Inc."},
    { 2098, /* 0x0832 */ "Kouwell Electronics Corp."},
    { 2099, /* 0x0833 */ "Sourcenext Corporation"},
    { 2101, /* 0x0835 */ "Action Star Enterprise Co., Ltd."},
    { 2105, /* 0x0839 */ "Samsung Techwin"},
    { 2106, /* 0x083A */ "Accton Technology Corporation"},
    { 2118, /* 0x0846 */ "NETGEAR, Inc."},
    { 2125, /* 0x084D */ "Minton Optic Industry Co., Ltd."},
    { 2129, /* 0x0851 */ "Macronix International Co., Ltd."},
    { 2130, /* 0x0852 */ "CSEM"},
    { 2136, /* 0x0858 */ "Hitachi Maxell Ltd."},
    { 2137, /* 0x0859 */ "Minolta Systems Laboratory, Inc."},
    { 2138, /* 0x085A */ "Xircom"},
    { 2154, /* 0x086A */ "Emagic Soft-und Hardware Gmbh"},
    { 2158, /* 0x086E */ "System TALKS Inc."},
    { 2159, /* 0x086F */ "MEC IMEX INC/HPT"},
    { 2160, /* 0x0870 */ "Metricom"},
    { 2163, /* 0x0873 */ "Xpeed Inc."},
    { 2169, /* 0x0879 */ "Comtrol Corporation"},
    { 2172, /* 0x087C */ "ADESSO/Kbtek America Inc."},
    { 2173, /* 0x087D */ "JATON Corporation"},
    { 2174, /* 0x087E */ "Fujitsu Computer Products of America"},
    { 2176, /* 0x0880 */ "APT Technologies Inc."},
    { 2194, /* 0x0892 */ "DioGraphy Inc."},
    { 2205, /* 0x089D */ "Icron Systems Inc."},
    { 2206, /* 0x089E */ "NST Co., Ltd."},
    { 2222, /* 0x08AE */ "Mace Group, Inc."},
    { 2228, /* 0x08B4 */ "Sorenson Vision, Inc."},
    { 2233, /* 0x08B9 */ "Tandy Corporation/Radio Shack"},
    { 2235, /* 0x08BB */ "Burr-Brown Japan, Ltd."},
    { 2237, /* 0x08BD */ "Citizen Watch Co., Ltd."},
    { 2244, /* 0x08C4 */ "Proxim, Inc."},
    { 2247, /* 0x08C7 */ "Key Nice Enterprise Co., Ltd."},
    { 2248, /* 0x08C8 */ "2Wire, Inc"},
    { 2250, /* 0x08CA */ "AIPTEK International Inc."},
    { 2254, /* 0x08CE */ "Long Well Electronics Corp."},
    { 2259, /* 0x08D3 */ "Virtual Ink"},
    { 2269, /* 0x08DD */ "Billionton Systems, Inc."},
    { 2271, /* 0x08DF */ "Spyrus Inc."},
    { 2276, /* 0x08E4 */ "Pioneer Corporation"},
    { 2277, /* 0x08E5 */ "LITRONIC"},
    { 2278, /* 0x08E6 */ "GEMPLUS"},
    { 2280, /* 0x08E8 */ "Integrated Memory Logic"},
    { 2281, /* 0x08E9 */ "Extended Systems, Inc."},
    { 2282, /* 0x08EA */ "Ericsson Inc."},
    { 2286, /* 0x08EE */ "CCSI/HESSO"},
    { 2288, /* 0x08F0 */ "Corex Technologies"},
    { 2289, /* 0x08F1 */ "CTI Electronics Corporation"},
    { 2293, /* 0x08F5 */ "SYSTEC Co., Ltd."},
    { 2294, /* 0x08F6 */ "Logic 3 International Limited"},
    { 2296, /* 0x08F8 */ "Keen Top International Enterprise Co., Ltd."},
    { 2298, /* 0x08FA */ "CAERE"},
    { 2299, /* 0x08FB */ "Socket Communications"},
    { 2300, /* 0x08FC */ "Sicon International"},
    { 2301, /* 0x08FD */ "Digianswer A/S"},
    { 2303, /* 0x08FF */ "AuthenTec, Inc."},
    { 2305, /* 0x0901 */ "VST Technologies"},
    { 2310, /* 0x0906 */ "FARADAY Technology Corp."},
    { 2314, /* 0x090A */ "Trumpion Microelectronics Inc"},
    { 2315, /* 0x090B */ "Neurosmith"},
    { 2316, /* 0x090C */ "Feiya Technology Corporation"},
    { 2317, /* 0x090D */ "MULTIPORT Computer Vertriebs GmbH"},
    { 2318, /* 0x090E */ "Shining Technology, Inc."},
    { 2319, /* 0x090F */ "Fujitsu Devices Inc."},
    { 2320, /* 0x0910 */ "Alation Systems, Inc."},
    { 2321, /* 0x0911 */ "Philips Speech Processing"},
    { 2322, /* 0x0912 */ "Voquette, Inc."},
    { 2325, /* 0x0915 */ "GlobeSpan, Inc."},
    { 2327, /* 0x0917 */ "SmartDisk Corporation"},
    { 2334, /* 0x091E */ "Garmin International"},
    { 2337, /* 0x0921 */ "GoHubs, inc."},
    { 2338, /* 0x0922 */ "Dymo-CoStar Corporation"},
    { 2339, /* 0x0923 */ "IC Media Corporation"},
    { 2340, /* 0x0924 */ "Xerox"},
    { 2343, /* 0x0927 */ "Summus, Ltd."},
    { 2344, /* 0x0928 */ "Oxford Semiconductor Ltd."},
    { 2345, /* 0x0929 */ "American Biometric Company"},
    { 2347, /* 0x092B */ "Sena Technologies, Inc."},
    { 2352, /* 0x0930 */ "Toshiba Corporation"},
    { 2353, /* 0x0931 */ "Harmonic Data Systems Ltd."},
    { 2354, /* 0x0932 */ "Crescentec Corporation"},
    { 2355, /* 0x0933 */ "Quantum Corp."},
    { 2356, /* 0x0934 */ "Netcom Systems"},
    { 2361, /* 0x0939 */ "Lumberg, Inc."},
    { 2362, /* 0x093A */ "Pixart Imaging, Inc."},
    { 2363, /* 0x093B */ "Plextor"},
    { 2366, /* 0x093E */ "J.S.T. Mfg. Co., Ltd."},
    { 2367, /* 0x093F */ "OLYMPIA Telecom Vertriebs GmbH"},
    { 2368, /* 0x0940 */ "Japan Storage Battery Co., Ltd."},
    { 2369, /* 0x0941 */ "Photobit Corporation"},
    { 2370, /* 0x0942 */ "i2Go.com, LLC"},
    { 2371, /* 0x0943 */ "HCL Technologies India Private Limited"},
    { 2373, /* 0x0945 */ "PASCO Scientific"},
    { 2381, /* 0x094D */ "Cable Television Laboratories"},
    { 2385, /* 0x0951 */ "Kingston Technology Company"},
    { 2388, /* 0x0954 */ "RPM Systems Corporation"},
    { 2389, /* 0x0955 */ "NVIDIA"},
    { 2390, /* 0x0956 */ "Bsquare"},
    { 2391, /* 0x0957 */ "Agilent Technologies, Inc."},
    { 2392, /* 0x0958 */ "BioLink Technologies International, Inc."},
    { 2393, /* 0x0959 */ "Cologne Chip AG"},
    { 2394, /* 0x095A */ "Portsmith"},
    { 2395, /* 0x095B */ "Medialogic Corporation"},
    { 2396, /* 0x095C */ "K-Tec Electronics"},
    { 2397, /* 0x095D */ "Polycom, Inc."},
    { 2408, /* 0x0968 */ "Catalyst Enterprises, Inc."},
    { 2417, /* 0x0971 */ "Gretag-Macbeth AG"},
    { 2419, /* 0x0973 */ "Schlumberger"},
    { 2420, /* 0x0974 */ "Eye Communication Systems, Inc"},
    { 2421, /* 0x0975 */ "OL'E Communications, Inc."},
    { 2422, /* 0x0976 */ "Adirondack Wire & Cable"},
    { 2423, /* 0x0977 */ "Lightsurf Technologies"},
    { 2424, /* 0x0978 */ "Beckhoff Gmbh"},
    { 2425, /* 0x0979 */ "Jeilin Technology Corp., Ltd."},
    { 2426, /* 0x097A */ "Minds At Work LLC"},
    { 2427, /* 0x097B */ "Knudsen Engineering Limited"},
    { 2428, /* 0x097C */ "Marunix Co., Ltd."},
    { 2429, /* 0x097D */ "Rosun Technologies, Inc."},
    { 2431, /* 0x097F */ "Barun Electronics Co. Ltd."},
    { 2444, /* 0x098C */ "Vitana Corporation"},
    { 2445, /* 0x098D */ "INDesign"},
    { 2446, /* 0x098E */ "Integrated Intellectual Property Inc."},
    { 2447, /* 0x098F */ "Kenwood TMI Corporation"},
    { 2454, /* 0x0996 */ "Integrated Telecom Express, Inc."},
    { 2467, /* 0x09A3 */ "PairGain Technologies"},
    { 2468, /* 0x09A4 */ "Contech Research, Inc."},
    { 2469, /* 0x09A5 */ "VCON Telecommunications"},
    { 2470, /* 0x09A6 */ "Poinchips"},
    { 2471, /* 0x09A7 */ "Data Transmission Network Corp."},
    { 2472, /* 0x09A8 */ "Shinestar Enterprise Co., Ltd."},
    { 2473, /* 0x09A9 */ "Smart Card Technologies Co., Ltd."},
    { 2474, /* 0x09AA */ "Intersil Corporation"},
    { 2483, /* 0x09B3 */ "Altius Solutions, Inc."},
    { 2484, /* 0x09B4 */ "MDS Telephone Systems"},
    { 2485, /* 0x09B5 */ "Celltrix Technology Co., Ltd."},
    { 2497, /* 0x09C1 */ "Arris Interactive LLC"},
    { 2498, /* 0x09C2 */ "NISCA Corporation"},
    { 2499, /* 0x09C3 */ "ACTIVCARD, INC."},
    { 2500, /* 0x09C4 */ "ACTiSYS Corporation"},
    { 2501, /* 0x09C5 */ "Memory Corporation"},
    { 2508, /* 0x09CC */ "Workbit Corporation"},
    { 2509, /* 0x09CD */ "Psion Connect Ltd."},
    { 2510, /* 0x09CE */ "City Electronics Ltd."},
    { 2511, /* 0x09CF */ "Electronics Testing Center, Taiwan"},
    { 2513, /* 0x09D1 */ "NeoMagic Inc."},
    { 2514, /* 0x09D2 */ "Vreelin Engineering Inc."},
    { 2515, /* 0x09D3 */ "COM ONE"},
    { 2521, /* 0x09D9 */ "Jungo"},
    { 2522, /* 0x09DA */ "A-FOUR TECH CO., LTD."},
    { 2523, /* 0x09DB */ "ComputerBoards Inc."},
    { 2524, /* 0x09DC */ "AIMEX Corporation"},
    { 2525, /* 0x09DD */ "Fellowes Manufacturing Co."},
    { 2527, /* 0x09DF */ "Addonics Technologies Corp."},
    { 2533, /* 0x09E5 */ "Jo-Dan International, Inc."},
    { 2534, /* 0x09E6 */ "Silutia, Inc."},
    { 2535, /* 0x09E7 */ "Real 3D, Inc."},
    { 2536, /* 0x09E8 */ "AKAI  professional M.I. Corp."},
    { 2537, /* 0x09E9 */ "CHEN-SOURCE INC."},
    { 2549, /* 0x09F5 */ "ARESCOM"},
    { 2550, /* 0x09F6 */ "RocketChips, Inc."},
    { 2551, /* 0x09F7 */ "EDU-SCIENCE (H.K.) LIMITED"},
    { 2552, /* 0x09F8 */ "SoftConnex"},
    { 2553, /* 0x09F9 */ "Bay Associates"},
    { 2554, /* 0x09FA */ "Mtek Vision"},
    { 2555, /* 0x09FB */ "Altera"},
    { 2559, /* 0x09FF */ "Gain Technology Corp."},
    { 2560, /* 0x0A00 */ "Liquid Audio"},
    { 2561, /* 0x0A01 */ "ViA, Inc."},
    { 2571, /* 0x0A0B */ "Cybex Computer Products Corporation"},
    { 2577, /* 0x0A11 */ "Xentec Incorporated"},
    { 2578, /* 0x0A12 */ "Cambridge Silicon Radio Ltd."},
    { 2579, /* 0x0A13 */ "Telebyte Inc."},
    { 2580, /* 0x0A14 */ "Spacelabs Medical Inc."},
    { 2581, /* 0x0A15 */ "Scalar Corporation"},
    { 2582, /* 0x0A16 */ "Trek Technology (S) Pte Ltd"},
    { 2583, /* 0x0A17 */ "Asahi Optical Co., Ltd."},
    { 2584, /* 0x0A18 */ "Heidelberger Druckmaschinen AG"},
    { 2585, /* 0x0A19 */ "Hua Geng Technologies Inc."},
    { 2593, /* 0x0A21 */ "Medtronic Physio Control Corp."},
    { 2594, /* 0x0A22 */ "Century Semiconductor USA, Inc."},
    { 2595, /* 0x0A23 */ "NDS Technologies Israel Ltd."},
    { 2617, /* 0x0A39 */ "Gilat Satellite Networks Ltd."},
    { 2618, /* 0x0A3A */ "PentaMedia Co., Ltd."},
    { 2620, /* 0x0A3C */ "NTT DoCoMo,Inc."},
    { 2621, /* 0x0A3D */ "Varo Vision"},
    { 2627, /* 0x0A43 */ "Boca Systems Inc."},
    { 2628, /* 0x0A44 */ "TurboLinux"},
    { 2629, /* 0x0A45 */ "Look&Say co., Ltd."},
    { 2630, /* 0x0A46 */ "Davicom Semiconductor, Inc."},
    { 2631, /* 0x0A47 */ "Hirose Electric"},
    { 2632, /* 0x0A48 */ "I/O Interconnect"},
    { 2635, /* 0x0A4B */ "Fujitsu Media Devices Limited"},
    { 2636, /* 0x0A4C */ "COMPUTEX Co., Ltd."},
    { 2637, /* 0x0A4D */ "Evolution Electronics Ltd."},
    { 2638, /* 0x0A4E */ "Steinberg Soft-und Hardware GmbH"},
    { 2639, /* 0x0A4F */ "Litton Systems Inc."},
    { 2640, /* 0x0A50 */ "Mimaki Engineering Co, Ltd."},
    { 2641, /* 0x0A51 */ "Sony Electronics Inc."},
    { 2642, /* 0x0A52 */ "JEBSEE ELECTRONICS CO., LTD."},
    { 2643, /* 0x0A53 */ "Portable Peripheral Co., Ltd."},
    { 2650, /* 0x0A5A */ "Electronics For Imaging, Inc."},
    { 2651, /* 0x0A5B */ "EASICS NV"},
    { 2652, /* 0x0A5C */ "Broadcom Corp."},
    { 2653, /* 0x0A5D */ "Diatrend Corporation"},
    { 2654, /* 0x0A5E */ "Spinnaker Systems Inc."},
    { 2655, /* 0x0A5F */ "Eltron Card Printer Products"},
    { 2661, /* 0x0A65 */ "FullAudio, Inc."},
    { 2662, /* 0x0A66 */ "ClearCube Technology"},
    { 2663, /* 0x0A67 */ "Medeli Electronics Co, Ltd."},
    { 2664, /* 0x0A68 */ "COMAIDE Corporation"},
    { 2665, /* 0x0A69 */ "Chroma ate Inc."},
    { 2666, /* 0x0A6A */ "Newcom Inc."},
    { 2667, /* 0x0A6B */ "Green House Co., Ltd."},
    { 2668, /* 0x0A6C */ "Integrated Circuit Systems Inc."},
    { 2669, /* 0x0A6D */ "UPS Manufacturing"},
    { 2670, /* 0x0A6E */ "Benwin"},
    { 2671, /* 0x0A6F */ "Core Technology, Inc."},
    { 2672, /* 0x0A70 */ "International Game Technology"},
    { 2673, /* 0x0A71 */ "VIPColor Technologies USA, Inc."},
    { 2674, /* 0x0A72 */ "Sanwa Denshi"},
    { 2685, /* 0x0A7D */ "NSTL, Inc."},
    { 2686, /* 0x0A7E */ "Octagon Systems Corporation"},
    { 2687, /* 0x0A7F */ "AVerMedia MicroSystems"},
    { 2688, /* 0x0A80 */ "Rexon Technology Corp., Ltd"},
    { 2689, /* 0x0A81 */ "CHESEN ELECTRONICS CORP."},
    { 2690, /* 0x0A82 */ "SYSCAN"},
    { 2691, /* 0x0A83 */ "NextComm, Inc."},
    { 2692, /* 0x0A84 */ "Maui Innovative Peripherals"},
    { 2693, /* 0x0A85 */ "IDEXX LABS"},
    { 2694, /* 0x0A86 */ "NITGen Co., Ltd."},
    { 2700, /* 0x0A8C */ "Tecmar"},
    { 2701, /* 0x0A8D */ "Picturetel"},
    { 2702, /* 0x0A8E */ "Japan Aviation Electronics Industry Ltd. (JAE)"},
    { 2703, /* 0x0A8F */ "Young Chang Co. Ltd."},
    { 2704, /* 0x0A90 */ "Candy Technology Co., Ltd."},
    { 2705, /* 0x0A91 */ "Globlink Technology Inc."},
    { 2706, /* 0x0A92 */ "EGO SYStems Inc."},
    { 2707, /* 0x0A93 */ "C Technologies AB (publ)"},
    { 2708, /* 0x0A94 */ "Intersense"},
    { 2723, /* 0x0AA3 */ "Lava Computer Mfg. Inc."},
    { 2724, /* 0x0AA4 */ "Develco Elektronik"},
    { 2725, /* 0x0AA5 */ "First International Digital"},
    { 2726, /* 0x0AA6 */ "Perception Digital Limited"},
    { 2727, /* 0x0AA7 */ "Wincor Nixdorf GmbH &Co KG"},
    { 2728, /* 0x0AA8 */ "TriGem Computer, Inc."},
    { 2729, /* 0x0AA9 */ "Baromtec Co."},
    { 2730, /* 0x0AAA */ "Japan CBM Corporation"},
    { 2731, /* 0x0AAB */ "Vision Shape Europe SA."},
    { 2732, /* 0x0AAC */ "iCompression Inc."},
    { 2733, /* 0x0AAD */ "Rohde & Schwarz GmbH & Co. KG"},
    { 2734, /* 0x0AAE */ "Nitsuko Corporation"},
    { 2735, /* 0x0AAF */ "digitalway co., ltd."},
    { 2736, /* 0x0AB0 */ "Arrow Strong Electronics CO. LTD"},
    { 2755, /* 0x0AC3 */ "SANYO Semiconductor Company Micro"},
    { 2756, /* 0x0AC4 */ "LECO CORPORATION"},
    { 2757, /* 0x0AC5 */ "I & C Corporation"},
    { 2758, /* 0x0AC6 */ "Singing Electrons, Inc."},
    { 2759, /* 0x0AC7 */ "Panwest Corporation"},
    { 2764, /* 0x0ACC */ "Koga Electronics Co."},
    { 2765, /* 0x0ACD */ "ID Tech"},
    { 2766, /* 0x0ACE */ "ZyDAS Technology Corporation"},
    { 2767, /* 0x0ACF */ "Intoto, Inc."},
    { 2768, /* 0x0AD0 */ "Intellix Corp."},
    { 2769, /* 0x0AD1 */ "Remotec Technology Ltd."},
    { 2770, /* 0x0AD2 */ "Service & Quality Technology Co., Ltd."},
    { 2787, /* 0x0AE3 */ "Allion Computer Inc."},
    { 2788, /* 0x0AE4 */ "Taito Corporation"},
    { 2789, /* 0x0AE5 */ "MacroSystem Digital Video AG"},
    { 2790, /* 0x0AE6 */ "EVI, Inc."},
    { 2791, /* 0x0AE7 */ "Neodym Systems Inc."},
    { 2792, /* 0x0AE8 */ "System Support Co., Ltd."},
    { 2793, /* 0x0AE9 */ "North Shore Circuit Design L.L.P."},
    { 2794, /* 0x0AEA */ "SciEssence, LLC"},
    { 2795, /* 0x0AEB */ "TTP Communications Ltd."},
    { 2796, /* 0x0AEC */ "Neodio Technologies Corporation"},
    { 2806, /* 0x0AF6 */ "SILVER I CO., LTD."},
    { 2807, /* 0x0AF7 */ "B2C2, Inc."},
    { 2812, /* 0x0AFC */ "Zaptronix Ltd"},
    { 2813, /* 0x0AFD */ "Tateno Dennou, Inc."},
    { 2814, /* 0x0AFE */ "Cummins Engine Company"},
    { 2815, /* 0x0AFF */ "Jump Zone Network Products, Inc."},
    { 2816, /* 0x0B00 */ "INGENICO"},
    { 2830, /* 0x0B0E */ "GN Netcom"},
    { 2831, /* 0x0B0F */ "AVID Technology"},
    { 2832, /* 0x0B10 */ "Pcally"},
    { 2833, /* 0x0B11 */ "I Tech Solutions Co., Ltd."},
    { 2846, /* 0x0B1E */ "Electronic Warfare Assoc., Inc. (EWA)"},
    { 2847, /* 0x0B1F */ "Insyde Software Corp."},
    { 2848, /* 0x0B20 */ "TransDimension Inc."},
    { 2849, /* 0x0B21 */ "Yokogawa Electric Corporation"},
    { 2850, /* 0x0B22 */ "Japan System Development Co. Ltd."},
    { 2851, /* 0x0B23 */ "Pan-Asia Electronics Co., Ltd."},
    { 2852, /* 0x0B24 */ "Link Evolution Corp."},
    { 2855, /* 0x0B27 */ "Ritek Corporation"},
    { 2856, /* 0x0B28 */ "Kenwood Corporation"},
    { 2860, /* 0x0B2C */ "Village Center, Inc."},
    { 2864, /* 0x0B30 */ "NewHeights Software"},
    { 2867, /* 0x0B33 */ "Contour Design, Inc."},
    { 2871, /* 0x0B37 */ "Hitachi ULSI Systems Co., Ltd."},
    { 2873, /* 0x0B39 */ "Omnidirectional Control Technology Inc."},
    { 2874, /* 0x0B3A */ "IPaxess"},
    { 2875, /* 0x0B3B */ "Bromax Communications, Inc."},
    { 2876, /* 0x0B3C */ "Olivetti Techcenter"},
    { 2881, /* 0x0B41 */ "Hal Corporation"},
    { 2887, /* 0x0B47 */ "Sportbug.com, Inc"},
    { 2888, /* 0x0B48 */ "TechnoTrend AG"},
    { 2889, /* 0x0B49 */ "ASCII Corporation"},
    { 2894, /* 0x0B4E */ "Musical Electronics Ltd."},
    { 2896, /* 0x0B50 */ "Dumpries Company Limited"},
    { 2898, /* 0x0B52 */ "Colorado MicroDisplay, Inc"},
    { 2900, /* 0x0B54 */ "Sinbon Electronics Co., Ltd."},
    { 2902, /* 0x0B56 */ "TYI Systems Ltd."},
    { 2903, /* 0x0B57 */ "Beijing HanwangTechnology Co. Ltd."},
    { 2905, /* 0x0B59 */ "Lake Communications Ltd."},
    { 2906, /* 0x0B5A */ "Corel Corporation"},
    { 2911, /* 0x0B5F */ "Green Electronics Co., Ltd."},
    { 2912, /* 0x0B60 */ "Nsine Limited"},
    { 2913, /* 0x0B61 */ "NEC Viewtechnology, Ltd."},
    { 2914, /* 0x0B62 */ "Orange Micro, Inc."},
    { 2915, /* 0x0B63 */ "ADLink Technology Inc."},
    { 2916, /* 0x0B64 */ "Wonderful Wire Cable Co., Ltd"},
    { 2917, /* 0x0B65 */ "Expert Magnetics Corp."},
    { 2921, /* 0x0B69 */ "CasheVision"},
    { 2922, /* 0x0B6A */ "Maxim Integrated Products"},
    { 2927, /* 0x0B6F */ "Nagano Japan Radio Co., Ltd"},
    { 2928, /* 0x0B70 */ "PortalPlayer, Inc"},
    { 2929, /* 0x0B71 */ "SHIN-EI Sangyo Co., Ltd."},
    { 2930, /* 0x0B72 */ "Embedded Wireless Technology Co. Ltd."},
    { 2931, /* 0x0B73 */ "Computone Corp."},
    { 2937, /* 0x0B79 */ "Sunrise Telecom, Inc."},
    { 2938, /* 0x0B7A */ "Telencomm"},
    { 2939, /* 0x0B7B */ "Taiko Denki Co., Ltd."},
    { 2940, /* 0x0B7C */ "ITRAN Communications Ltd."},
    { 2941, /* 0x0B7D */ "Astrodesign, Inc."},
    { 2948, /* 0x0B84 */ "Rextron Technology, Inc."},
    { 2949, /* 0x0B85 */ "Elkat Electronics (M) SDN. BHD."},
    { 2950, /* 0x0B86 */ "Exputer Systems, Inc."},
    { 2951, /* 0x0B87 */ "Plus-One I & T Inc."},
    { 2952, /* 0x0B88 */ "Sigma Koki Co., Ltd. Technology Center"},
    { 2953, /* 0x0B89 */ "Advanced Digital Broadcast Ltd."},
    { 2965, /* 0x0B95 */ "ASIX Electronics Corp."},
    { 2966, /* 0x0B96 */ "SEWON TELECOM"},
    { 2967, /* 0x0B97 */ "02 Micro, Inc."},
    { 2968, /* 0x0B98 */ "Playmates Toys Inc."},
    { 2969, /* 0x0B99 */ "Audio International, Inc."},
    { 2973, /* 0x0B9D */ "Softprotec Co."},
    { 2975, /* 0x0B9F */ "Chippo Technologies"},
    { 2991, /* 0x0BAF */ "U.S. Robotics"},
    { 2992, /* 0x0BB0 */ "Concord Camera Corp."},
    { 2993, /* 0x0BB1 */ "Infinilink Corporation"},
    { 2994, /* 0x0BB2 */ "Ambit Microsystems Corporation"},
    { 2995, /* 0x0BB3 */ "Ofuji Technology"},
    { 2996, /* 0x0BB4 */ "High Tech Computer, Corp. (HTC)"},
    { 2997, /* 0x0BB5 */ "Murata Manufacturing Co., Ltd."},
    { 2998, /* 0x0BB6 */ "Network Alchemy"},
    { 2999, /* 0x0BB7 */ "Joytech Computer Company Limited"},
    { 3000, /* 0x0BB8 */ "Hitachi Semiconductor and Devices Sales Co., Ltd."},
    { 3001, /* 0x0BB9 */ "Eiger M & C CO., LTD."},
    { 3002, /* 0x0BBA */ "ZACCESS Systems"},
    { 3003, /* 0x0BBB */ "General Meters Corporation"},
    { 3004, /* 0x0BBC */ "Assistive Technology, Inc."},
    { 3005, /* 0x0BBD */ "System Connection, Inc"},
    { 3008, /* 0x0BC0 */ "Knilink Technology Inc."},
    { 3009, /* 0x0BC1 */ "FUW YNG ELECTRONICS COMPANY LTD"},
    { 3010, /* 0x0BC2 */ "Seagate RSS LLC"},
    { 3011, /* 0x0BC3 */ "IPWireless, Inc."},
    { 3012, /* 0x0BC4 */ "Microcube Corp."},
    { 3013, /* 0x0BC5 */ "JCN Co., Ltd."},
    { 3014, /* 0x0BC6 */ "ExWAY Inc."},
    { 3015, /* 0x0BC7 */ "X10 Wireless Technology, Inc."},
    { 3016, /* 0x0BC8 */ "Telmax Communications"},
    { 3017, /* 0x0BC9 */ "ECI Telecom Ltd"},
    { 3018, /* 0x0BCA */ "Startek Engineering Incorporated"},
    { 3019, /* 0x0BCB */ "Perfect Technic Enterprise Co. LTD"},
    { 3034, /* 0x0BDA */ "Realtek Semiconductor Corp."},
    { 3035, /* 0x0BDB */ "Ericsson Business Mobile Networks BV"},
    { 3036, /* 0x0BDC */ "Y Media Corporation"},
    { 3037, /* 0x0BDD */ "Orange PCS"},
    { 3042, /* 0x0BE2 */ "Kanda Tsushin Kogyo Co., LTD"},
    { 3043, /* 0x0BE3 */ "TOYO Corporation"},
    { 3044, /* 0x0BE4 */ "Elka Taiwan LTD"},
    { 3045, /* 0x0BE5 */ "DOME imaging systems, inc"},
    { 3046, /* 0x0BE6 */ "Dong Guan Humen Wonderful Wire Cable Factory"},
    { 3054, /* 0x0BEE */ "LTK Industries Ltd."},
    { 3055, /* 0x0BEF */ "Way2Call Communications"},
    { 3056, /* 0x0BF0 */ "Pace Micro Technology PLC"},
    { 3057, /* 0x0BF1 */ "Intracom S.A."},
    { 3058, /* 0x0BF2 */ "Konexx"},
    { 3063, /* 0x0BF7 */ "Sunny Giken inc."},
    { 3064, /* 0x0BF8 */ "Fujitsu-Siemens-Computers"},
    { 3076, /* 0x0C04 */ "MOTO Development Group, Inc."},
    { 3077, /* 0x0C05 */ "Appian Graphics"},
    { 3078, /* 0x0C06 */ "Hasbro Games Inc."},
    { 3079, /* 0x0C07 */ "Infinite Data Storage LTD"},
    { 3080, /* 0x0C08 */ "ei Corporation"},
    { 3081, /* 0x0C09 */ "Comjet Information System"},
    { 3082, /* 0x0C0A */ "Highpoint Technologies, Inc."},
    { 3083, /* 0x0C0B */ "Dura Micro, Inc."},
    { 3093, /* 0x0C15 */ "Iris Graphics"},
    { 3094, /* 0x0C16 */ "Gyration, Inc."},
    { 3095, /* 0x0C17 */ "Cyberboard A/S"},
    { 3096, /* 0x0C18 */ "SynerTek Korea, Inc."},
    { 3097, /* 0x0C19 */ "cyberPIXIE, Inc."},
    { 3098, /* 0x0C1A */ "Silicon Motion, Inc."},
    { 3099, /* 0x0C1B */ "MIPS TECHNOLOGIES"},
    { 3100, /* 0x0C1C */ "Hang Zhou Silan Electronics Co. Ltd"},
    { 3106, /* 0x0C22 */ "Tally Printer Corporation"},
    { 3107, /* 0x0C23 */ "Lernout + Hauspie (L + H)"},
    { 3109, /* 0x0C25 */ "SAMPO CORPORATION"},
    { 3125, /* 0x0C35 */ "Eagletron Inc."},
    { 3126, /* 0x0C36 */ "E INK CORPORATION"},
    { 3127, /* 0x0C37 */ "e.Digital"},
    { 3128, /* 0x0C38 */ "Der An Electric Wire & Cable Co. Ltd."},
    { 3129, /* 0x0C39 */ "IFR"},
    { 3130, /* 0x0C3A */ "Furui Precise Component (Kunshan) Co., Ltd"},
    { 3131, /* 0x0C3B */ "Komatsu Ltd."},
    { 3132, /* 0x0C3C */ "Radius Co., Ltd."},
    { 3133, /* 0x0C3D */ "Innocom, Inc."},
    { 3134, /* 0x0C3E */ "NEXTCELL INC."},
    { 3140, /* 0x0C44 */ "Motorola iDEN"},
    { 3141, /* 0x0C45 */ "Sonix Technology Co., Ltd."},
    { 3154, /* 0x0C52 */ "Sealevel Systems, Inc."},
    { 3155, /* 0x0C53 */ "ViewPLUS Inc."},
    { 3156, /* 0x0C54 */ "GLORY LTD."},
    { 3157, /* 0x0C55 */ "Spectrum Digital Inc."},
    { 3158, /* 0x0C56 */ "Billion Bright Limited"},
    { 3159, /* 0x0C57 */ "Imaginative Design Operation Co. Ltd."},
    { 3160, /* 0x0C58 */ "Vidar Systems Corporation"},
    { 3162, /* 0x0C5A */ "TRS International Mfg., Inc."},
    { 4268, /* 0x10AC */ "Honeywell, Inc."},
    { 4496, /* 0x1190 */ "Tripace"},
    { 4622, /* 0x120E */ "HUDSON SOFT CO., LTD."},
    { 5480, /* 0x1568 */ "Sunf Pu Technology Co., Ltd"},
    { 5638, /* 0x1606 */ "UMAX Data Systems Inc."},
    { 5640, /* 0x1608 */ "Inside Out Networks"},
    { 5736, /* 0x1668 */ "Actiontec Electronics, Inc."},
    { 5782, /* 0x1696 */ "Hitachi Video and Information System, Inc."},
    { 7867, /* 0x1EBB */ "NuCORE Technology, Inc."},
    { 8888, /* 0x22B8 */ "Motorola PCS"},
    { 8890, /* 0x22BA */ "Technology Innovation International Co., Ltd."},
    { 8964, /* 0x2304 */ "Pinnacle Systems, Inc."},
    {10393, /* 0x2899 */ "Toptronic Industrial Co., Ltd."},
    {13878, /* 0x3636 */ "INVIBRO"},
    {14627, /* 0x3923 */ "National Instruments"},
    {16700, /* 0x413C */ "Dell Computer Corp."},
    {21827, /* 0x5543 */ "UC-Logic Technology Corp."},
    {21930, /* 0x55AA */ "OnSpec Electronic Inc."},
    {25452, /* 0x636C */ "CoreLogic, Inc."},
    {27253, /* 0x6A75 */ "Shanghai Jujo Electronics Co., Ltd."},
    {32902, /* 0x8086 */ "Intel Corporation"},
    { 0x00, "End"}
};

#endif /* __VNDRLIST_H__ */

